<?php

namespace wbb\system\option;

use wcf\data\option\Option;
use wcf\system\option\AbstractOptionType;
use wcf\system\Regex;
use wcf\system\WCF;

/**
 * Color option chooser for thread rate stars
 *
 * @author    Olaf Braun
 * @copyright 2013-2021 Olaf Braun - Software Development
 * @license   WBB-Elite.de License <https://lizenz.wbb-elite.de/lizenz.html>
 * @package   de.wbb-elite.thread.rate
 * @category  Thread review
 */
class ColorOptionType extends AbstractOptionType {
	
	/**
	 * @see    \wcf\system\option\IOptionType::getData()
	 */
	public function getData(Option $option, $newValue) {
		// ignore everything except well-formed rgba()
		$regEx = new Regex('rgba\(\d{1,3}, \d{1,3}, \d{1,3}, (1|1\.00?|0|0?\.[0-9]{1,2})\)');
		if ($regEx->match($newValue)) {
			return $newValue;
		}
		
		return 'rgba(0,0,0,0)';
	}
	
	/**
	 * Returns the html code of the form element for the given option of this
	 * option type.
	 *
	 * @param    \wcf\data\option\Option $option
	 * @param    mixed                   $value
	 *
	 * @return    string
	 */
	public function getFormElement(Option $option, $value) {
		WCF::getTPL()->assign([
			'option' => $option,
			'value'  => $value,
		]);
		
		return WCF::getTPL()->fetch('colorOptionType', "wbb");
	}
}
